@@ -17,13 +17,19 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
- 
+
 #ifndef HEADER_APP_GLOM
 #define HEADER_APP_GLOM
 
 #include "bakery/bakery.h"
 #include "frame_glom.h"
 
+
+namespace Glom
+{
+
+class Window_Translations;
+
 class App_Glom : public Bakery::App_WithDoc_Gtk
 {
 public:
@@ -52,6 +58,14 @@ public:
   void fill_menu_tables();
   void fill_menu_reports(const Glib::ustring& table_name);
 
+  ///Whether to show the generated SQL queries on stdout, for debugging.
+  bool get_show_sql_debug() const;
+
+  ///Whether to show the generated SQL queries on stdout, for debugging.
+  void set_show_sql_debug(bool val = true);
+
+  static App_Glom* get_application();
+
 protected:
   virtual void init_layout(); //override.
   virtual void init_menus_file(); //override.
@@ -66,13 +80,20 @@ protected:
   virtual void on_menu_help_contents();
   virtual void on_menu_userlevel_developer();
   virtual void on_menu_userlevel_operator();
+  virtual void on_menu_file_save_as_example();
+  virtual void on_menu_developer_changelanguage();
+  virtual void on_menu_developer_translations();
+  virtual void on_window_translations_hide();
+
+  virtual void on_menu_file_close(); //override.
 
   virtual void on_userlevel_changed(AppState::userlevels userlevel);
 
   virtual Bakery::App* new_instance(); //Override
 
-  virtual bool recreate_database(bool& user_cancelled); //return indicates success.
-  
+  bool recreate_database(bool& user_cancelled); //return indicates success.
+  void stop_self_hosting_of_document_database();
+
   typedef Bakery::App_WithDoc_Gtk type_base;
 
   //Widgets:
@@ -86,11 +107,16 @@ protected:
 
   Gtk::VBox* m_pBoxTop;
   Frame_Glom* m_pFrame;
-  Gtk::Label* m_pStatus;
+
+  Window_Translations* m_window_translations;
 
   Glib::RefPtr<Gtk::ActionGroup> m_refNavTablesActionGroup, m_refNavReportsActionGroup;
   type_listActions m_listNavTableActions, m_listNavReportActions;
   Gtk::UIManager::ui_merge_id m_menu_tables_ui_merge_id, m_menu_reports_ui_merge_id;
+
+  bool m_show_sql_debug;
 };
 
+} //namespace Glom
+
 #endif //HEADER_APP_GLOM
